<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */
namespace FiloBlu\OrderAdditionalData\Model;

use \Magento\Framework\Api\AttributeValueFactory;
/**
 * OAD Order Item Additional Data
 */
class AdditionalData implements \FiloBlu\OrderAdditionalData\Api\AdditionalDataInterface
{

    protected $_customAttributes;
    protected $_attributeValueFactory;
    
    public function __construct(
        AttributeValueFactory $attributeValueFactory
    ){
        $this->_attributeValueFactory = $attributeValueFactory;
        $this->_customAttributes=array();
    }
    
     /**
     * Get an attribute value.
     *
     * @param string $attributeCode
     * @return \Magento\Framework\Api\AttributeInterface|null
     */
    public function getCustomAttribute($attributeCode){
        return $this->_customAttributes[$attributeCode];
    }

    /**
     * Set an attribute value for a given attribute code
     *
     * @param string $attributeCode
     * @param mixed $attributeValue
     * @return $this
     */
    public function setCustomAttribute($attributeCode, $attributeValue){
        if(!array_key_exists($attributeCode, $this->_customAttributes)){
            $newAttribute = $this->_attributeValueFactory->create();
            $newAttribute->setAttributeCode($attributeCode);     
            $this->_customAttributes[$attributeCode]=$newAttribute;
        }
        $this->_customAttributes[$attributeCode]->setValue($attributeValue);
        return $this;
    }

    /**
     * Retrieve custom attributes values.
     *
     * @return \Magento\Framework\Api\AttributeInterface[]|null
     */
    public function getCustomAttributes(){        
        return $this->_customAttributes;
    }

    /**
     * Set array of custom attributes
     *
     * @param \Magento\Framework\Api\AttributeInterface[] $attributes
     * @return $this
     * @throws \LogicException
     */
    public function setCustomAttributes(array $attributes){
        foreach($attributes as $attribute){
            $this->_customAttributes[$attribute->getAttributeCode()] = $attribute;
        }
    }
    
    
    
}